"""gustaf/gustaf/mesh_maker.py.

MeshMaker that triangulates and tetrahedralizes with segment input.
"""
